@@ -2,6 +2,7 @@ package mustgather
 
 import (
 	"bufio"
+	"context"
 	"fmt"
 	"io"
 	"math/rand"
@@ -41,7 +42,7 @@ var (
 	mustGatherLong = templates.LongDesc(`
 		Launch a pod to gather debugging information
 
-		This command will launch a pod in a temporary namespace on your cluster that gathers 
+		This command will launch a pod in a temporary namespace on your cluster that gathers
 		debugging information and then downloads the gathered information.
 
 		Experimental: This command is under active development and may change without notice.
@@ -54,10 +55,10 @@ var (
 		# gather information with a specific local folder to copy to
 		  oc adm must-gather --dest-dir=/local/directory
 
-		# gather information using multiple plug-in images 
+		# gather information using multiple plug-in images
 		  oc adm must-gather --image=quay.io/kubevirt/must-gather --image=quay.io/openshift/origin-must-gather
 
-		# gather information using a specific image stream plug-in 
+		# gather information using a specific image stream plug-in
 		  oc adm must-gather --image-stream=openshift/must-gather:latest
 
 		# gather information using a specific image, command, and pod-dir
@@ -84,6 +85,7 @@ func NewMustGatherCommand(f kcmdutil.Factory, streams genericclioptions.IOStream
 	cmd.Flags().StringSliceVar(&o.ImageStreams, "image-stream", o.ImageStreams, "Specify an image stream (namespace/name:tag) containing a must-gather plugin image to run.")
 	cmd.Flags().StringVar(&o.DestDir, "dest-dir", o.DestDir, "Set a specific directory on the local machine to write gathered data to.")
 	cmd.Flags().StringVar(&o.SourceDir, "source-dir", o.SourceDir, "Set the specific directory on the pod copy the gathered data from.")
+	cmd.Flags().Int64Var(&o.Timeout, "timeout", 600, "The length of time to gather data, in seconds. Defaults to 10 minutes.")
 	cmd.Flags().BoolVar(&o.Keep, "keep", o.Keep, "Do not delete temporary resources when command completes.")
 	cmd.Flags().MarkHidden("keep")
 
@@ -177,7 +179,7 @@ func parseImageStreamTagString(s string) (string, string, string) {
 }
 
 func (o *MustGatherOptions) resolveImageStreamTag(namespace, name, tag string) (string, error) {
-	imageStream, err := o.ImageClient.ImageStreams(namespace).Get(name, metav1.GetOptions{})
+	imageStream, err := o.ImageClient.ImageStreams(namespace).Get(context.TODO(), name, metav1.GetOptions{})
 	if err != nil {
 		return "", err
 	}
@@ -203,6 +205,7 @@ type MustGatherOptions struct {
 	Images       []string
 	ImageStreams []string
 	Command      []string
+	Timeout      int64
 	Keep         bool
 
 	RsyncRshCmd string
@@ -224,7 +227,7 @@ func (o *MustGatherOptions) Run() error {
 	var err error
 
 	// create namespace
-	ns, err := o.Client.CoreV1().Namespaces().Create(&corev1.Namespace{
+	ns, err := o.Client.CoreV1().Namespaces().Create(context.TODO(), &corev1.Namespace{
 		ObjectMeta: metav1.ObjectMeta{
 			GenerateName: "openshift-must-gather-",
 			Labels: map[string]string{
@@ -234,14 +237,14 @@ func (o *MustGatherOptions) Run() error {
 				"oc.openshift.io/command": "oc adm must-gather",
 			},
 		},
-	})
+	}, metav1.CreateOptions{})
 	if err != nil {
 		return err
 	}
 	o.PrinterCreated.PrintObj(ns, o.LogOut)
 	if !o.Keep {
 		defer func() {
-			if err := o.Client.CoreV1().Namespaces().Delete(ns.Name, nil); err != nil {
+			if err := o.Client.CoreV1().Namespaces().Delete(context.TODO(), ns.Name, metav1.DeleteOptions{}); err != nil {
 				fmt.Printf("%v", err)
 				return
 			}
@@ -249,14 +252,14 @@ func (o *MustGatherOptions) Run() error {
 		}()
 	}
 
-	clusterRoleBinding, err := o.Client.RbacV1().ClusterRoleBindings().Create(o.newClusterRoleBinding(ns.Name))
+	clusterRoleBinding, err := o.Client.RbacV1().ClusterRoleBindings().Create(context.TODO(), o.newClusterRoleBinding(ns.Name), metav1.CreateOptions{})
 	if err != nil {
 		return err
 	}
 	o.PrinterCreated.PrintObj(clusterRoleBinding, o.LogOut)
 	if !o.Keep {
 		defer func() {
-			if err := o.Client.RbacV1().ClusterRoleBindings().Delete(clusterRoleBinding.Name, &metav1.DeleteOptions{}); err != nil {
+			if err := o.Client.RbacV1().ClusterRoleBindings().Delete(context.TODO(), clusterRoleBinding.Name, metav1.DeleteOptions{}); err != nil {
 				fmt.Printf("%v", err)
 				return
 			}
@@ -267,7 +270,7 @@ func (o *MustGatherOptions) Run() error {
 	// create pods
 	var pods []*corev1.Pod
 	for _, image := range o.Images {
-		pod, err := o.Client.CoreV1().Pods(ns.Name).Create(o.newPod(o.NodeName, image))
+		pod, err := o.Client.CoreV1().Pods(ns.Name).Create(context.TODO(), o.newPod(o.NodeName, image), metav1.CreateOptions{})
 		if err != nil {
 			return err
 		}
@@ -305,7 +308,7 @@ func (o *MustGatherOptions) Run() error {
 
 			// copy the gathered files into the local destination dir
 			log("downloading gather output")
-			pod, err = o.Client.CoreV1().Pods(pod.Namespace).Get(pod.Name, metav1.GetOptions{})
+			pod, err = o.Client.CoreV1().Pods(pod.Namespace).Get(context.TODO(), pod.Name, metav1.GetOptions{})
 			if err != nil {
 				log("gather output not downloaded: %v\n", err)
 				errs <- fmt.Errorf("unable to download output from pod %s: %s", pod.Name, err)
@@ -388,9 +391,9 @@ func newPrefixWriter(out io.Writer, prefix string) io.Writer {
 
 func (o *MustGatherOptions) waitForPodRunning(pod *corev1.Pod) error {
 	phase := pod.Status.Phase
-	err := wait.PollImmediate(time.Second, 10*time.Minute, func() (bool, error) {
+	err := wait.PollImmediate(time.Duration(o.Timeout)*time.Second, time.Minute, func() (bool, error) {
 		var err error
-		if pod, err = o.Client.CoreV1().Pods(pod.Namespace).Get(pod.Name, metav1.GetOptions{}); err != nil {
+		if pod, err = o.Client.CoreV1().Pods(pod.Namespace).Get(context.TODO(), pod.Name, metav1.GetOptions{}); err != nil {
 			// at this stage pod should exist, we've been gathering container logs, so error if not found
 			if kerrors.IsNotFound(err) {
 				return true, err
@@ -414,9 +417,9 @@ func (o *MustGatherOptions) waitForPodRunning(pod *corev1.Pod) error {
 }
 
 func (o *MustGatherOptions) waitForGatherContainerRunning(pod *corev1.Pod) error {
-	return wait.PollImmediate(time.Second, 10*time.Minute, func() (bool, error) {
+	return wait.PollImmediate(time.Duration(o.Timeout)*time.Second, time.Minute, func() (bool, error) {
 		var err error
-		if pod, err = o.Client.CoreV1().Pods(pod.Namespace).Get(pod.Name, metav1.GetOptions{}); err == nil {
+		if pod, err = o.Client.CoreV1().Pods(pod.Namespace).Get(context.TODO(), pod.Name, metav1.GetOptions{}); err == nil {
 			if len(pod.Status.InitContainerStatuses) == 0 {
 				return false, nil
 			}
