@@ -10,7 +10,7 @@ import (
 	"k8s.io/cli-runtime/pkg/genericclioptions"
 	"k8s.io/client-go/kubernetes"
 	"k8s.io/kubectl/pkg/polymorphichelpers"
-	"k8s.io/kubernetes/pkg/controller"
+	"k8s.io/kubectl/pkg/util/podutils"
 
 	appsv1 "github.com/openshift/api/apps/v1"
 )
@@ -30,7 +30,7 @@ func NewAttachablePodForObjectFn(delegate polymorphichelpers.AttachablePodForObj
 
 			selector := labels.SelectorFromSet(t.Spec.Selector)
 			f := func(pods []*v1.Pod) sort.Interface {
-				return sort.Reverse(controller.ActivePods(pods))
+				return sort.Reverse(podutils.ActivePods(pods))
 			}
 			pod, _, err := polymorphichelpers.GetFirstPod(coreClient.CoreV1(), t.Namespace, selector.String(), 1*time.Minute, f)
 			return pod, err
